==> cppad_2014.00.00.3.orig.tar.gz: cppad-20140000.3/doc/_old_atomic_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'deprecated.xml',
'old_atomic.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_down1 = [
'include_deprecated.xml',
'fundeprecated.xml',
'omp_max_thread.xml',
'tracknewdel.xml',
'omp_alloc.xml',
'memory_leak.xml',
'epsilon.xml',
'test_vector.xml',
'cppad_ipopt_nlp.xml',
'old_atomic.xml'
];
var list_down0 = [
'old_reciprocal.cpp.xml',
'old_usead_1.cpp.xml',
'old_usead_2.cpp.xml',
'old_tan.cpp.xml',
'old_mat_mul.cpp.xml'
];
var list_current0 = [
'old_atomic.xml#Syntax',
'old_atomic.xml#Syntax.Define Function',
'old_atomic.xml#Syntax.Use Function',
'old_atomic.xml#Syntax.Callback Routines',
'old_atomic.xml#Syntax.Free Static Memory',
'old_atomic.xml#Purpose',
'old_atomic.xml#Partial Implementation',
'old_atomic.xml#CPPAD_USER_ATOMIC',
'old_atomic.xml#CPPAD_USER_ATOMIC.Tvector',
'old_atomic.xml#CPPAD_USER_ATOMIC.Base',
'old_atomic.xml#ok',
'old_atomic.xml#id',
'old_atomic.xml#k',
'old_atomic.xml#n',
'old_atomic.xml#m',
'old_atomic.xml#tx',
'old_atomic.xml#ty',
'old_atomic.xml#ty.forward',
'old_atomic.xml#ty.reverse',
'old_atomic.xml#afun',
'old_atomic.xml#afun.ax',
'old_atomic.xml#afun.ay',
'old_atomic.xml#afun.Parallel Mode',
'old_atomic.xml#forward',
'old_atomic.xml#forward.Usage',
'old_atomic.xml#forward.vx',
'old_atomic.xml#forward.vy',
'old_atomic.xml#reverse',
'old_atomic.xml#reverse.Usage',
'old_atomic.xml#reverse.py',
'old_atomic.xml#reverse.px',
'old_atomic.xml#for_jac_sparse',
'old_atomic.xml#for_jac_sparse.Usage',
'old_atomic.xml#for_jac_sparse.q',
'old_atomic.xml#for_jac_sparse.r',
'old_atomic.xml#for_jac_sparse.s',
'old_atomic.xml#rev_jac_sparse',
'old_atomic.xml#rev_jac_sparse.Usage',
'old_atomic.xml#rev_jac_sparse.q',
'old_atomic.xml#rev_jac_sparse.s',
'old_atomic.xml#rev_jac_sparse.r',
'old_atomic.xml#rev_hes_sparse',
'old_atomic.xml#rev_hes_sparse.Usage',
'old_atomic.xml#rev_hes_sparse.q',
'old_atomic.xml#rev_hes_sparse.r',
'old_atomic.xml#rev_hes_sparse.s',
'old_atomic.xml#rev_hes_sparse.t',
'old_atomic.xml#rev_hes_sparse.u',
'old_atomic.xml#rev_hes_sparse.v',
'old_atomic.xml#clear',
'old_atomic.xml#clear.Restriction',
'old_atomic.xml#Example',
'old_atomic.xml#Example.Simple',
'old_atomic.xml#Example.Use AD',
'old_atomic.xml#Example.Tangent Function',
'old_atomic.xml#Example.Matrix Multiplication'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_old_atomic_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'deprecated.xml',
'old_atomic.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'include_deprecated.xml',
'fundeprecated.xml',
'comparechange.xml',
'omp_max_thread.xml',
'tracknewdel.xml',
'omp_alloc.xml',
'memory_leak.xml',
'epsilon.xml',
'test_vector.xml',
'cppad_ipopt_nlp.xml',
'old_atomic.xml',
'zdouble.xml'
];
var list_down0 = [
'old_reciprocal.cpp.xml',
'old_usead_1.cpp.xml',
'old_usead_2.cpp.xml',
'old_tan.cpp.xml',
'old_mat_mul.cpp.xml'
];
var list_current0 = [
'old_atomic.xml#Deprecated 2013-05-27',
'old_atomic.xml#Syntax Function',
'old_atomic.xml#Syntax Function.Use Function',
'old_atomic.xml#Syntax Function.Callback Routines',
'old_atomic.xml#Syntax Function.Free Static Memory',
'old_atomic.xml#Purpose',
'old_atomic.xml#Partial Implementation',
'old_atomic.xml#CPPAD_USER_ATOMIC',
'old_atomic.xml#CPPAD_USER_ATOMIC.Tvector',
'old_atomic.xml#CPPAD_USER_ATOMIC.Base',
'old_atomic.xml#ok',
'old_atomic.xml#id',
'old_atomic.xml#k',
'old_atomic.xml#n',
'old_atomic.xml#m',
'old_atomic.xml#tx',
'old_atomic.xml#ty',
'old_atomic.xml#ty.forward',
'old_atomic.xml#ty.reverse',
'old_atomic.xml#afun',
'old_atomic.xml#afun.ax',
'old_atomic.xml#afun.ay',
'old_atomic.xml#afun.Parallel Mode',
'old_atomic.xml#forward',
'old_atomic.xml#forward.Usage',
'old_atomic.xml#forward.vx',
'old_atomic.xml#forward.vy',
'old_atomic.xml#reverse',
'old_atomic.xml#reverse.Usage',
'old_atomic.xml#reverse.py',
'old_atomic.xml#reverse.px',
'old_atomic.xml#for_jac_sparse',
'old_atomic.xml#for_jac_sparse.Usage',
'old_atomic.xml#for_jac_sparse.q',
'old_atomic.xml#for_jac_sparse.r',
'old_atomic.xml#for_jac_sparse.s',
'old_atomic.xml#rev_jac_sparse',
'old_atomic.xml#rev_jac_sparse.Usage',
'old_atomic.xml#rev_jac_sparse.q',
'old_atomic.xml#rev_jac_sparse.s',
'old_atomic.xml#rev_jac_sparse.r',
'old_atomic.xml#rev_hes_sparse',
'old_atomic.xml#rev_hes_sparse.Usage',
'old_atomic.xml#rev_hes_sparse.q',
'old_atomic.xml#rev_hes_sparse.r',
'old_atomic.xml#rev_hes_sparse.s',
'old_atomic.xml#rev_hes_sparse.t',
'old_atomic.xml#rev_hes_sparse.u',
'old_atomic.xml#rev_hes_sparse.v',
'old_atomic.xml#clear',
'old_atomic.xml#clear.Restriction',
'old_atomic.xml#Example',
'old_atomic.xml#Example.Simple',
'old_atomic.xml#Example.Use AD',
'old_atomic.xml#Example.Tangent Function',
'old_atomic.xml#Example.Matrix Multiplication'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
